@@ -1,4 +1,5 @@
 import unittest
+from dataclasses import dataclass
 
 from jinsi.jsonutil import dumpjson, loadjson_all
 
@@ -13,6 +14,11 @@ class X:
             yield count, item
             count += 1
 
+@dataclass
+class Z:
+    foo: int
+    bar: str
+
 
 class JsonDumpTests(unittest.TestCase):
 
@@ -34,6 +40,12 @@ class JsonDumpTests(unittest.TestCase):
         expected = ({}, {}, [])
         self.assertEqual(expected, result)
 
+    def test_dataclass(self):
+        with self.assertRaises(TypeError):
+            dumpjson(Z(1, 'quux'))
+        res = dumpjson(Z(1, 'quux'), encode_dict=True)
+        self.assertEqual('{"foo":1,"bar":"quux"}', res)
+
 
 if __name__ == '__main__':
     unittest.main()
